@@ -5,7 +5,7 @@ fn main() {
 	let clone_data = Arc::new(0);
 	let add_data = Arc::new(100);
 
-	my_enclose(enclose!((mut *clone_data, *add_data) || {
+	my_enclose(enclose!((mut *clone_data, *add_data,) || {
 		// (mut *clone_data, *add_data) ->
 		// let mut clone_data = *clone_data;
 		// let add_data = *add_data;
