@@ -1,4 +1,4 @@
-//Copyright (c) 2019-2024 #UlinProject Denis Kotlyarov (Денис Котляров)
+//Copyright (c) 2019-2025 #UlinProject Denis Kotlyarov (Денис Котляров)
 
 //-----------------------------------------------------------------------------
 //Licensed under the Apache License, Version 2.0 (the "License");
@@ -35,7 +35,7 @@
 //OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 //SOFTWARE.
 
-// #Ulin Project 1819 2022 2024
+// #Ulin Project 1819 2025
 
 /*!
 A convenient macro, for cloning values into a closure.
@@ -347,6 +347,42 @@ mod var;
 ///
 #[macro_export]
 macro_rules! enclose {
+	[
+		// (a, b) async || true
+		( $($enc_args:tt)* ) async move || $($b:tt)*
+	] => {{ // async, empty args
+		$crate::enclose_var! {
+			$( $enc_args )*
+		}
+		async move || $($b)*
+	}};
+	[
+		// (a, b) async move |c, d| true
+		( $($enc_args:tt)* ) async move | $($args:tt),* | $($b:tt)*
+	] => {{ // async, args
+		$crate::enclose_var! {
+			$( $enc_args )*
+		}
+		async move | $($args),* | $($b)*
+	}};
+	[
+		// (a, b) async || true
+		( $($enc_args:tt)* ) async || $($b:tt)*
+	] => {{ // async, empty args
+		$crate::enclose_var! {
+			$( $enc_args )*
+		}
+		async || $($b)*
+	}};
+	[
+		// (a, b) async |c, d| true
+		( $($enc_args:tt)* ) async | $($args:tt),* | $($b:tt)*
+	] => {{ // async, args
+		$crate::enclose_var! {
+			$( $enc_args )*
+		}
+		async | $($args),* | $($b)*
+	}};
 	[
 		// (a, b) move || true
 		( $($enc_args:tt)* ) move || $($b:tt)*
@@ -410,18 +446,4 @@ macro_rules! enclose {
 /// copying values into the closure.
 ///
 /// Alternative short record `enclose`.
-#[macro_export]
-macro_rules! enc {
-	[
-		// (a, b) move || true
-		// (a, b) move |c, d| true
-		// (a, b) || true
-		// (a, b) |c, d| true
-		// (a, b) true
-		$($tt:tt)*
-	] => {
-		$crate::enclose! {
-			$($tt)*
-		}
-	};
-}
+pub use enclose as enc;
\ No newline at end of file
